%define name    intel-media
%define version 24.2.5
%define rel     1

%define major   7
%define libname %mklibname igfxcmrt %{major}
%define develname %mklibname igfxcmrt -d

Name:           %{name}
Version:        %{version}
Release:        %mkrel %{rel}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Kernel and hardware
License:        MIT
URL:            https://github.com/intel/media-driver
Source0:        %{url}/archive/%{name}-%{version}.tar.gz
#

# patches from git upstream
#
Patch0100:	0001-Media-Common-VP-Move-MTL-Media-CCS-registry-to-commo.patch
Patch0101:	0002-Encode-Enable-REXT-on-Linux.patch
Patch0102:	0003-Decode-Disable-VT-scalability-on-ADL.patch
Patch0103:	0004-Encode-Add-AVC-BRC-error-handling.patch
Patch0104:	0005-Encode-Reduce-MHW-CMD-parser-perf-impact.patch
Patch0105:	0006-Fix-double-free-crash-when-create-mmd-fail.patch
Patch0106:	0007-Media-Common-VP-Disable-overloaded-virtual-being-hid.patch
Patch0107:	0008-Decode-Decode-roubustness-enhancement-for-invalid-re.patch
Patch0108:	0009-VP-fix-TGL-hdr-state-size-related-PF.patch
Patch0109:	0010-VP-fix-legacy-code-xml-dump-error.patch
Patch0110:	0011-Encode-Fix-AV1-Linux-numtilegroup-10-issue.patch
Patch0111:	0012-Media-Common-VP-MCPY-CP-small-local-bar-force-VE-cop.patch
Patch0112:	0013-VP-CPU-latency-optimize.patch
Patch0113:	0014-Encode-Rext444-unaligned-surface-p-frame-corruption-.patch
Patch0114:	0015-Media-Common-VP-LNL-VP-common-Decode-MHW-upstream.patch
Patch0115:	0016-Media-Common-VP-xe2-keyword-update.patch
Patch0116:	0017-VP-Fix-PotPlayer-PageFault-issue.patch
Patch0117:	0018-VP-pront-not-DW-align.patch
Patch0118:	0019-Encode-AV1-enable-sliding-window-for-CBR.patch
Patch0119:	0020-Encode-Add-random-access-B-16-support-for-ICQ-mode.patch
Patch0120:	0021-Media-Common-VP-MCPY-VPL-usage-copy-completion-wait-.patch
Patch0121:	0022-VP-Fix-typo-for-potplayer-page-fault-legacy-path.patch

BuildRequires:  cmake
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(igdgmm) >= 12.3.0
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(libva)
BuildRequires:  intel-gmmlib-devel >= 22.3.20

# This package relies on igdgmm which relies on intel asm
ExclusiveArch:  x86_64 

%description
Intel Media SDK provides a plain C API to access hardware-accelerated video
decode, encode and filtering on Intel Gen graphics hardware platforms.
Implementation written in C++ 11 with parts in C-for-Media (CM).

Supported video encoders: HEVC, AVC, MPEG-2, JPEG, VP9 Supported video decoders:
HEVC, AVC, VP8, VP9, MPEG-2, VC1, JPEG Supported video pre-processing filters:
Color Conversion, Deinterlace, Denoise, Resize, Rotate, Composition

%package -n     vaapi-driver-%{name}
Summary:        Hardware-accelerated video processing driver for VAAPI Intel
Group:          System/Kernel and hardware
 
%description -n vaapi-driver-%{name}
This package contains the driver needed to access hardware 
 

%package -n     %{libname}
Summary:        Hardware-accelerated video processing on Intel integrated GPUs Library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
 
%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with igfxcmrt library.
 
%package -n     %{develname}
Summary:        SDK for hardware-accelerated video processing on Intel integrated GPUs
Group:          Development/C++
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
 
%description -n %{develname}
This package contains the headers that programmers will need to develop
applications which will use igfxcmrt library.

%files -n vaapi-driver-%{name}
%{_libdir}/dri/*_drv_video.so
 
%files -n %{libname}
%{_libdir}/libigfxcmrt.so.%{major}{,.*}
 
%files -n %{develname}
%dir %{_includedir}/igfxcmrt
%{_includedir}/igfxcmrt/cm_*.h
%{_libdir}/libigfxcmrt.so
%{_libdir}/pkgconfig/igfxcmrt.pc


%prep
%autosetup -p1 -n media-driver-intel-media-%{version}

%build
%cmake \
    -DBUILD_DISPATCHER=ON \
    -DBUILD_SAMPLES=OFF \
    -DBUILD_TESTS=ON \
    -DBUILD_TOOLS=OFF \
    -DENABLE_OPENCL=ON \
    -DENABLE_WAYLAND=ON \
    -DENABLE_X11=ON \
    -DENABLE_X11_DRI3=ON \
    -DUSE_SYSTEM_GTEST=ON \

%cmake_build

%install
%cmake_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'



%changelog
* Mon Jul 01 2024 ghibo <ghibo> 24.2.5-1.mga10
+ Revision: 2078523
- Update to release 24.2.5.
- Merge patches from git upstream.
- Fix gmmlib BR.
- Update to version 24.1.5

* Thu Feb 22 2024 ghibo <ghibo> 24.1.3-1.mga10
+ Revision: 2043164
- Update to version 24.1.3.
- Merge patches from git upstream.

* Sat Dec 16 2023 ghibo <ghibo> 23.4.3-1.mga10
+ Revision: 2018325
- Update to version 23.4.3.
- Drop patches merged upstream.

* Tue Sep 19 2023 ghibo <ghibo> 23.3.3-1.mga10
+ Revision: 1988064
- Update to release 23.3.3.
- Merge patches from git upstream.

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-2.mga9
+ Revision: 1949666
- Merge patch from git upstream to fix a memleak

* Sat Mar 18 2023 ghibo <ghibo> 23.1.3-1.mga9
+ Revision: 1949643
- Update to release 23.1.3.
- Drop patches merged upstream.

* Sat Feb 25 2023 ghibo <ghibo> 23.1.2-1.mga9
+ Revision: 1945394
- Update to release 23.1.2.
- Merge patch from git upstream to fix jpeg decode MD5 mismatch.
- Merge patch from git upstream to fix NULL pointer issue.

* Thu Feb 09 2023 ghibo <ghibo> 23.1.1-1.mga9
+ Revision: 1939727
- Update to release 23.1.1.
- Drop Patch0, merged upstream.
- Versioning igdgmm in BuildRequires.

* Thu Mar 31 2022 kekepower <kekepower> 22.3.0-1.mga9
+ Revision: 1836901
- Add upstream patch to fix build with gcc 12.0.1
- Update to version 22.3.0
- Update to version 22.1.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jul 10 2020 zezinho <zezinho> 20.2.0-1.mga8
+ Revision: 1604322
- new version 20.2.0

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-2.mga8
+ Revision: 1565321
- fix url

* Mon Apr 06 2020 zezinho <zezinho> 19.3.0-1.mga8
+ Revision: 1565275
- imported package intel-media

